@@ -62,7 +62,7 @@ class AzureML(BackendBase):
     def get_name(self):
         return "aml"
 
-    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, args):
+    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args):
         '''
         This method is called to allow the backend to inject needed shell commands before the user cmd.  At the
         time this is called, files can still be added to snapshot_dir.
@@ -121,6 +121,7 @@ class AzureML(BackendBase):
             wrapped_parts = ["python", "-u", fn_shim, " ".join(sh_parts)]
             run_specs["cmd_parts"] = wrapped_parts
 
+
     def get_default_docker_image(self, use_gpu):
         if use_gpu:
             # recommended for IPT w/GPU: 
@@ -610,10 +611,10 @@ class AzureML(BackendBase):
         docker_name = args["docker"]
         creds_required = False
 
-        docker_image, login_server, docker_registry = self.config.get_docker_info(target, docker_name, required=False)
+        docker_image, login_server, docker_registry, sing_dict = self.config.get_docker_info(target, docker_name, required=False)
 
         # aml doesn't like/recognized docker.io
-        if login_server == "docker.io":
+        if self.get_name() == "aml" and login_server == "docker.io":
             login_server = None
 
         if not docker_image:
@@ -630,7 +631,7 @@ class AzureML(BackendBase):
         else:
             container_registry = None
 
-        return container_registry, docker_image
+        return container_registry, docker_image, sing_dict
 
     def create_estimator(self, job_id, workspace, aml_ws_name, xt_exper_name, aml_exper_name, run_name, code_dir, target_fn, arg_dict, 
         compute_target, node_id, nodes, fake_submit, args):
@@ -695,7 +696,7 @@ class AzureML(BackendBase):
             compute_target=compute_target, username=username, description=description, aggregate_dest=aggregate_dest, 
             node_id=node_id, args=args)
 
-        container_registry, docker_image = self.get_docker_container_registry(args)
+        container_registry, docker_image, _, = self.get_docker_container_registry(args)
 
         framework = args["framework"]
         if framework:
@@ -789,7 +790,7 @@ class AzureML(BackendBase):
         if fake_submit or self.submit_logs:
             # for testing (this should match exact args used in estimator ctr below)
             if use_environment:
-                serializable_environment = {"environment_variables": env_vars, "docker": {"enabled": aml_use_docker, "gpu_support": use_gpu,
+                serializable_environment = {"environment_variables": env_vars, "docker": {"enabled": aml_use_docker, # deprecated: "gpu_support": use_gpu,
                     "base_image": docker_image}}
 
                 self.serializable_estimator = {"source_directory": code_dir, "script_params": arg_dict, "compute_target": actual_target, 
@@ -813,7 +814,7 @@ class AzureML(BackendBase):
                 environment.python.user_managed_dependencies = user_managed
 
                 environment.docker.enabled = aml_use_docker
-                environment.docker.gpu_support = use_gpu            # deprecated?
+                #environment.docker.gpu_support = use_gpu            # deprecated
 
                 if container_registry:
                     environment.docker.base_image_registry = container_registry
@@ -1014,8 +1015,8 @@ class AzureML(BackendBase):
             trainer = estimator
 
         run_name, monitor_cmd, aml_run_name, aml_run_number, aml_run_id = \
-            self.run_aml_job(job_id, ws_name, aml_ws_name, trainer, experiment, xt_exper_name, aml_exper_name, compute_target, code_dir, first_run_name, 
-                box_name, node_index, repeat_count, fake_submit, args)
+            self.run_job_on_service(job_id, ws_name, aml_ws_name, trainer, experiment, xt_exper_name, aml_exper_name, compute_target, code_dir, first_run_name, 
+                box_name, node_index, repeat_count, fake_submit, arg_parts, args)
 
         if show_aml_run_name:
             console.print("  {} (AML: {}/Run {})".format(run_name, aml_exper_name, aml_run_number))
@@ -1035,6 +1036,8 @@ class AzureML(BackendBase):
             node_info["aml_run_number"] = aml_run_number
             node_info["aml_run_id"] = aml_run_id
             node_info["run_name"] = run_name
+            node_info["job_id"] = job_id
+            node_info["node_id"] = node_id
 
             # update mongo db info for run with cluster and service_job_id
             # DO WE STILL NEED THIS?  Aug-08-2020
@@ -1048,8 +1051,8 @@ class AzureML(BackendBase):
 
         return node_info
 
-    def run_aml_job(self, job_id, workspace, aml_ws_name, trainer, experiment, xt_exper_name, aml_exper_name, compute_target, cwd, run_name, box_name, 
-            node_index, repeat, fake_submit, args):
+    def run_job_on_service(self, job_id, workspace, aml_ws_name, trainer, experiment, xt_exper_name, aml_exper_name, compute_target, cwd, run_name, box_name, 
+            node_index, repeat, fake_submit, arg_parts, args):
         monitor_cmd = None
 
         console.diag("before AML experiment.submit(trainer)")
@@ -1127,8 +1130,12 @@ class AzureML(BackendBase):
 
         FN_STDOUT_LOG = "azureml-logs/00_stdout.txt"
         FN_STDOUT2_LOG = "azureml-logs/70_driver_log.txt"
+        FN_STD_OUT_TXT = "user_logs/std_out.txt"
 
         run = self.get_node_run(service_node_info)
+        job_id = utils.safe_value(service_node_info, "job_id", service_node_info["aml_exper_name"].split("__")[3])
+        node_id =  utils.safe_value(service_node_info, "node_id", "node0")
+        workspace = service_node_info["ws"]
 
         # aml bug workaround
         run._output_logs_pattern = "azureml-logs/[\d]{2}.+\.txt"
@@ -1140,52 +1147,71 @@ class AzureML(BackendBase):
         new_text = None
         node_status = "queued"
         next_offset = None
+        found_file = False
 
-        # refresh run details (status and logs)
-        current_details = run.get_details() 
-        aml_status = current_details["status"] 
-        simple_status = self.get_simple_status(aml_status)
+        if log_name is None:
+            file_path = "user_logs/std_log.txt"
+        else:
+            file_path = os.path.basename(log_name)
 
-        if use_best_log:
-            # list of currently available logs
-            available_logs = run._get_logs(current_details)
-            if FN_STDOUT_LOG in available_logs:
-                next_log = FN_STDOUT_LOG
-            elif FN_STDOUT2_LOG in available_logs:
-                next_log = FN_STDOUT2_LOG
-            else:
-                # let AML pick best log 
-                next_log = Run._get_last_log_primary_instance(available_logs) if available_logs else None
-    
-            if available_logs and log_name != next_log:
-                # switching logs, so reset offset and remember new name
-                start_offset = 0
-                log_name = next_log
+        # try to first read from job storage (if task has completed)
+        if log_source != "live":
+            node_index = utils.node_index(node_id)
 
-        if log_name:
-            # reuse request for better perf (hopefully)
-            url = current_details["logFiles"][log_name]
+            job_path = "nodes/node{}/after/service_logs/{}".format(node_index, file_path)
+            if self.store.does_job_file_exist(workspace, job_id, job_path):
+                new_text = self.store.read_job_file(workspace, job_id, job_path)
+                aml_status = "completed"
+                simple_status = "completed"
+                found_file = True
+                log_source = "after_logs"
 
-            if not self.request:
-                self.request = urllib.request.Request(url)
-            elif self.request.full_url != url:
-                #self.request.close()
-                self.request = urllib.request.Request(url)
+        if not found_file:
+            # refresh run details (status and logs)
+            current_details = run.get_details() 
+            aml_status = current_details["status"] 
+            simple_status = self.get_simple_status(aml_status)
 
-            try:
-                with urllib.request.urlopen(self.request) as response:
-                    all_bytes = response.read()
-            except:
-                # treat any error as "log not yet available"
-                all_bytes = b""
+            if use_best_log:
+                # list of currently available logs
+                available_logs = run._get_logs(current_details)
+                if FN_STDOUT_LOG in available_logs:
+                    next_log = FN_STDOUT_LOG
+                elif FN_STDOUT2_LOG in available_logs:
+                    next_log = FN_STDOUT2_LOG
+                else:
+                    # let AML pick best log 
+                    next_log = Run._get_last_log_primary_instance(available_logs) if available_logs else None
+        
+                if available_logs and log_name != next_log:
+                    # switching logs, so reset offset and remember new name
+                    start_offset = 0
+                    log_name = next_log
 
-            if end_offset:
-                new_bytes = all_bytes[start_offset:1+end_offset]
-            else:
-                new_bytes = all_bytes[start_offset:]
+            if log_name:
+                # reuse request for better perf (hopefully)
+                url = current_details["logFiles"][log_name]
 
-            next_offset = start_offset + len(new_bytes)
-            new_text = new_bytes.decode(encoding)
+                if not self.request:
+                    self.request = urllib.request.Request(url)
+                elif self.request.full_url != url:
+                    #self.request.close()
+                    self.request = urllib.request.Request(url)
+
+                try:
+                    with urllib.request.urlopen(self.request) as response:
+                        all_bytes = response.read()
+                except:
+                    # treat any error as "log not yet available"
+                    all_bytes = b""
+
+                if end_offset:
+                    new_bytes = all_bytes[start_offset:1+end_offset]
+                else:
+                    new_bytes = all_bytes[start_offset:]
+
+                next_offset = start_offset + len(new_bytes)
+                new_text = new_bytes.decode(encoding)
 
         return {"new_text": new_text, "simple_status": simple_status, "log_name": log_name, "next_offset": next_offset, 
             "service_status": aml_status}
