@@ -58,7 +58,7 @@ class BackendBase(implements(BackendInterface)):
         pass
 
     # API 
-    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, args):
+    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args):
         '''
         This method is called to allow the backend to inject needed shell commands before the user cmd.  At the
         time this is called, files can still be added to snapshot_dir.
@@ -629,7 +629,7 @@ class BackendBase(implements(BackendInterface)):
 
         target = args["target"]
         docker_name = args["docker"]
-        docker_image, login_server, docker_registry = self.config.get_docker_info(target, docker_name, required=False)
+        docker_image, login_server, docker_registry, _ = self.config.get_docker_info(target, docker_name, required=False)
         docker_image = login_server + "/" + docker_image if login_server else docker_image
 
         if not docker_image:
@@ -1069,7 +1069,9 @@ class BackendBase(implements(BackendInterface)):
             self.append_export(cmds, var_name, '$({})'.format(now_cmd), fix_value=False)
 
     def append_pre_docker_cmds(self, cmds, args):
+        
         if not self.gen_for_windows:
+
             # show name of system
             self.append(cmds, "hostnamectl")
 
@@ -1115,6 +1117,10 @@ class BackendBase(implements(BackendInterface)):
             self.append(cmds, "echo run script to extract Azure Batch NODE and POOL ids > /dev/null")
             self.append(cmds, "python {} {} {} {} {} {}".format(constants.FN_BATCH_NODE_ID, batch_job_id, self.node_index, service, batch_url, batch_key))
 
+        elif self.get_name() == "singularity":
+            # on singularity, we must write long env var strings into a separate script
+            self.append(cmds, "export $(cat {} | xargs)".format(constants.FN_SET_ENV_VARS))
+
         # # TORCH version (is GPU available to torch?)
         # target_cmd = '''python -c "import torch; print('PyTorch:'.ljust(15) + ' ' + torch.__version__ + ', CUDA available: ' + str(torch.cuda.is_available()))"'''
         # self.append_package_test(cmds, "torch", target_cmd, "PyTorch")
@@ -1276,7 +1282,7 @@ class BackendBase(implements(BackendInterface)):
 
             # finally, write the full name of the docker image to a special file
             fn_image = os.path.join(bootstrap_dir, constants.FN_IMAGE_NAME)
-            docker_image, login_server, docker_registry = self.config.get_docker_info(self.compute, docker_name, required=False)
+            docker_image, login_server, _, _ = self.config.get_docker_info(self.compute, docker_name, required=False)
             full_image_name = login_server + "/" + docker_image if login_server and login_server != "docker.io" else docker_image
 
             file_utils.write_text_file(fn_image, full_image_name)
