@@ -110,7 +110,7 @@ class AzureBatch(BackendBase):
         '''
         return False
 
-    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, args):
+    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args):
         '''
         This method is called to allow the backend to inject needed shell commands before the user cmd.  At the
         time this is called, files can still be added to snapshot_dir.
@@ -674,7 +674,7 @@ class AzureBatch(BackendBase):
         target = self.compute
 
         # docker_name = args["docker"]
-        # docker_image, login_server, docker_registry = self.config.get_docker_info(target, docker_name, required=False)
+        # docker_image, login_server, docker_registry, sha256 = self.config.get_docker_info(target, docker_name, required=False)
 
         # if docker_image:
 
