@@ -54,7 +54,7 @@ class Philly(BackendBase):
     def get_name(self):
         return "philly"
 
-    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, args):
+    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args):
         '''
         This method is called to allow the backend to inject needed shell commands before the user cmd.  This 
         base implementation does so by generating a new script file and adding it to the snapshot_dir.
@@ -463,7 +463,7 @@ class Philly(BackendBase):
         queue = utils.safe_value(compute_def, "queue")      
 
         docker_name = args["docker"]
-        docker_image, login_server, docker_registry = self.config.get_docker_info(target, docker_name, required=True)
+        docker_image, login_server, docker_registry, _ = self.config.get_docker_info(target, docker_name, required=True)
 
         # philly wants these as a single name
         docker_image = login_server + "/" + docker_image if login_server else docker_image
