@@ -57,8 +57,7 @@ class PoolBackend(BackendBase):
         '''
         return False
 
-    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, 
-            args):
+    def adjust_run_commands(self, job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args):
         '''
         This method is called to allow the backend to inject needed shell commands before the user cmd.  This 
         base implementation does so by generating a new script file and adding it to the snapshot_dir.
