@@ -75,7 +75,7 @@ def capture_before_files_zip(store, source_dir, ws_name=None, run_name=None, ext
             before_files = [fn_zip]
             omit_files = []
 
-            if service_type in ["batch", "itp", "aml"]:
+            if service_type in ["batch", "itp", "aml", "singularity"]:
                 # add a copy of bootstrap files in parallel to the .zip file so they are available when we start to run
                 if service_type == "batch":
                     bootstrap_files = [constants.FN_WRAPPED_SH, constants.FN_WRAPPED_BAT, constants.FN_INNER_SH, \
@@ -88,7 +88,8 @@ def capture_before_files_zip(store, source_dir, ws_name=None, run_name=None, ext
                         bootstrap_files.append("code/mnist.py")
                 else:
                     bootstrap_files = [constants.FN_WRAPPED_SH, constants.FN_WRAPPED_BAT, constants.FN_EV, 
-                        constants.PY_RUN_CONTROLLER, constants.FN_MULTI_RUN_CONTEXT, constants.FN_AML_SHIM]      
+                        constants.PY_RUN_CONTROLLER, constants.FN_MULTI_RUN_CONTEXT, constants.FN_AML_SHIM, 
+                        constants.FN_SET_ENV_VARS] 
 
                 for bs in bootstrap_files:
                     fn_bs = source_dir + "/" + bs
