@@ -13,6 +13,7 @@ import psutil
 import requests
 import datetime
 import importlib
+import numpy as np
 
 from .client import Client
 from .console import console 
@@ -243,9 +244,13 @@ class CmdCore():
         return node_context
         
     def compute_run_indexes_for_node(self, total_run_count, node_count, node_index):
-        runs_per_node = math.ceil(total_run_count/node_count)
-        runs_last_node = total_run_count - (runs_per_node * (node_count-1))
-        node_run_count = runs_per_node if node_index < node_count-1 else runs_last_node
+        runs_per_node = math.floor(total_run_count/node_count)
+
+        # number of nodes that will have runs_per_node+1 (rest will have runs_per_node)
+        plus_one_count = total_run_count - (runs_per_node * node_count)
+
+        # compute number of runs for this node
+        node_run_count = 1+runs_per_node if node_index < plus_one_count else runs_per_node
 
         first_run_index = runs_per_node*node_index
         last_run_index = first_run_index + node_run_count - 1
@@ -276,7 +281,9 @@ class CmdCore():
 
         context.first_run_index = first_run_index
         context.last_run_index = last_run_index
-        context.max_delay = args["max_run_delay"]
+
+        # only apply run delays for jobs with multiple runs
+        context.max_delay = args["max_run_delay"] if total_run_count > 1 else 0
 
         context.ws = workspace
         context.working_dir = working_dir
@@ -332,6 +339,11 @@ class CmdCore():
         context.maximize_metric = args["maximize_metric"]
         context.report_rollup = args["report_rollup"]
 
+        # arguments for CCD HP search algorithm
+        context.goal_metric = args["goal_metric"]
+        context.max_passes = args["max_passes"]
+        context.runs_per_set = args["runs_per_set"]
+
         context.after_upload = args["after_upload"]
         #context.scrape = config.get("general", "scrape")
         context.log = args["log"]
@@ -344,6 +356,9 @@ class CmdCore():
         context.is_parent = context.search_style != "single"
         context.create_time = utils.get_arrow_time_str()
 
+        # controller sleep time
+        context.sleep_on_exit = args["sleep_on_exit"]
+
         # HPARAM search
         hp_config = args["hp_config"]
         if hp_config:
@@ -521,6 +536,16 @@ class CmdCore():
         file_utils.ensure_dir_exists(file=fn_context)
         workspace = args["workspace"]
 
+        # ensure values in runsets are JSON-compatible
+        def json_safe(rs):
+            for key, value in rs.items():
+                if isinstance(value, np.int64):
+                    rs[key] = int(value)
+            return rs
+
+        if runsets:
+            runsets = [json_safe(rs) for rs in runsets]
+
         mrc_data = { "context_by_nodes": context_by_nodes, "cmds": cmds, "runsets": runsets, "search_style": search_style }
         text = json.dumps(mrc_data, indent=4)
         with open(fn_context, "wt") as tfile:
@@ -592,7 +617,7 @@ class CmdCore():
 
         copied_files = capture.capture_before_files_zip(self.store, source_dir=source_dir, omit_files=omit_list, store_dest=store_dir,
             rerun_name=resume_name, job_id=job_id, zip_before=zip_type, remove_prefix_len=remove_prefix_len, upload_type=upload_type, 
-            service_type=service_type, ws_name=workspace)
+            service_type=service_type, ws_name=workspace, args=args)
 
         console.diag("after upload of {} to job".format(upload_type.upper()))
         return copied_files
