@@ -11,7 +11,7 @@ here, check to see if you need to also change it in psm.py.
 
 # Sync the BUILD string changes with: setup.py, CHANGELOG.md
 # Also, consider setting pytorch-xtlib docker image (in facotry_config.yaml) to new version just before releasing new XT
-BUILD = "version: 0.0.261, build: Mar-07-2022"
+BUILD = "version: 0.0.264, build: Mar-20-2022"
     
 INFO_CONTAINER_V1 = "xt-store-info"
 INFO_CONTAINER_V2 = "00-store-info"
@@ -137,6 +137,9 @@ FN_WRAPPED_SH = "__wrapped__.sh"
 FN_WRAPPED_BAT = "__wrapped__.bat"
 FN_EV = "__dockev__.txt"
 FN_AML_SHIM = "__aml_shim__.py"
+FN_SET_ENV_VARS = "__set_env_vars__.sh"
+FN_BUILD_STEPS_TEMPLATE = "build_steps_template.txt"
+
 FN_BATCH_HELPER = "__batch_helper__.sh"
 FN_BATCH_NODE_ID = "__batch_node_id__.py"
 
