@@ -859,7 +859,7 @@ class XTController(rpyc.Service):
 
             child_info = RunInfo(child_name, context.ws, cmd_parts, context.run_script, 
                 None, context, "running", True, parent_name=parent.run_name, mirror_close_func = self.stop_mirror_worker, 
-                node_id=self.node_id, run_index=run_index, store=self.store)
+                node_id=self.node_id, run_index=run_index, store=self.store, is_parent=False)
 
             parent.process_run_output("spawned: {}\n".format(child_name))
         else:
@@ -1134,11 +1134,14 @@ class XTController(rpyc.Service):
             self.concurrent = context.concurrent
             log_info("set concurrent", self.concurrent)
 
+        is_parent = context.is_parent      # or context.repeat is not None
         print("context.job_id=", context.job_id)
+        print("context.repeat=", context.repeat)
+        print("is_parent=", is_parent)
 
         run_info = RunInfo(run_name, context.ws, cmd_parts, run_script, context.repeat, context, "queued", True, 
             parent_name=None, parent_prep_needed=parent_prep_needed, mirror_close_func = self.stop_mirror_worker, 
-            node_id=self.node_id, run_index=None, store=self.store, max_delay=context.max_delay)
+            node_id=self.node_id, run_index=None, store=self.store, max_delay=context.max_delay, is_parent=is_parent)
 
         # log run QUEUED event 
         store = self.store
