@@ -385,6 +385,7 @@ class XTConfig():
         docker_image = None
         login_server = None
         docker_registry = None
+        sing_dict = {}
 
         compute_def = self.get_target_def(target)
 
@@ -400,6 +401,10 @@ class XTConfig():
             if not docker_image:
                 errors.config_error("Definition for docker '{}' is missing the required 'image' property".format(docker_name))
 
+            sing_dict["sing_wrap"] = utils.safe_value(env, "sing-wrap")
+            sing_dict["sha256"] = utils.safe_value(env, "sha256")
+            sing_dict["post_sing_steps"] = utils.safe_value(env, "post-sing-steps")
+
             registry_name = utils.safe_value(env, "registry")
             # if not registry_name:
             #     errors.config_error("Definition for docker '{}' is missing the required 'registry' property".format(docker_name))
@@ -416,8 +421,8 @@ class XTConfig():
             # all philly compute targets must specify a docker image
             errors.config_error("Philly compute target '{}' is missing the required 'docker' property (in XT config file)".format(target))
 
-        return docker_image, login_server, docker_registry
-
+        return docker_image, login_server, docker_registry, sing_dict
+        
     def get_target_desc(self, target, backend):
         '''
         returns a string describing the target (for logging and monitoring)
@@ -431,7 +436,7 @@ class XTConfig():
             queue = backend.queue
             target_str = "target={}, backend={}, cluster={}, vc={}, queue={}".format(target, backend_name, cluster, vc, queue)
 
-        elif backend_name in ["aml", "itp"]:
+        elif backend_name in ["aml", "itp", "singularity"]:
             service = compute_def["service"]
             compute = compute_def["compute"]
             target_str = "target={}, backend={}, service={}, compute={}".format(target, backend_name, service, compute)
