@@ -70,7 +70,7 @@ class RunSet():
         self.sample_mean = 0.
         self.sample_m2 = 0.
         self.post_mean = None
-        self.post_var = None
+        self.post_st_dev = None
         # A circular, doubly-linked list of RunSets, continually sorted by posterior mean in ascending order.
         self.sent = False  # The sentinel, for which dn is the best runset, and up is the worst.
         self.up = None  # The next best runset (or the sentinel).
@@ -85,15 +85,17 @@ class RunSet():
         N = self.sample_count
         if N == 0:
             self.post_mean = prior_mean
-            self.post_var = prior_var
+            self.post_st_dev = math.sqrt(prior_var)
         else:
             sample_mean = self.sample_mean
             sample_var = (prior_var + (N - 1) * self.get_sample_var()) / N  # Interpolation
             mean_numer = sample_var * prior_mean + N * prior_var * sample_mean
             var_numer = sample_var * prior_var
             denom = sample_var + N * prior_var
+            if denom <= 0.:
+                denom = 1.
             self.post_mean = mean_numer / denom
-            self.post_var = var_numer / denom
+            self.post_st_dev = math.sqrt(var_numer / denom)
 
     def insert(self, dn=None, up=None):
         ''' Inserts the runset into the list at either the current or specified location. '''
@@ -133,15 +135,12 @@ class RunSet():
             self.insert()
 
     def is_better_than(self, other):
-        # Higher mean is better.
-        if self.post_mean > other.post_mean:
+        self_lower_bound = self.post_mean - self.post_st_dev
+        other_lower_bound = other.post_mean - other.post_st_dev
+        # Higher lower-bound is better.
+        if self_lower_bound > other_lower_bound:
             return True
-        elif self.post_mean < other.post_mean:
-            return False
-        # Lower variance is better.
-        if self.post_var < other.post_var:
-            return True
-        elif self.post_var > other.post_var:
+        elif self_lower_bound < other_lower_bound:
             return False
         # Older is better.
         return self.runs[0].end_id < other.runs[0].end_id
@@ -226,7 +225,7 @@ class RunSetTrophy():
 
 
 class Run():
-    def __init__(self, run_summary, primary_metric, verbose=False, use_azure_storage=False):
+    def __init__(self, run_summary, primary_metric, maximize_metric, verbose=False, use_azure_storage=False):
         ''' Maintains the per-run information. '''
         if use_azure_storage:
             # run_summary comes from Azure Storage.
@@ -246,7 +245,10 @@ class Run():
                 elif event_type == "metrics":
                     metric_dict = event_dict["data"]
                     if primary_metric in metric_dict:
-                        self.value += float(metric_dict[primary_metric])
+                        if maximize_metric:
+                            self.value += float(metric_dict[primary_metric])
+                        else:
+                            self.value -= float(metric_dict[primary_metric])
                         self.skip = False
                 elif event_type == "created":
                     if self.run_name is not None:
@@ -272,7 +274,10 @@ class Run():
             self.end_id = run_summary['end_id']
             metrics = run_summary['metrics']
             if primary_metric in metrics:
-                self.value = float(metrics[primary_metric])
+                if maximize_metric:
+                    self.value = float(metrics[primary_metric])
+                else:
+                    self.value = -float(metrics[primary_metric])
                 self.hparams = run_summary['hparams']
             else:
                 self.skip = True
@@ -307,8 +312,8 @@ class Hyperparameter():
 
 class SearchHistory():
     ''' Loads, processes, and evaluates the runs of a single hyperparameter search job. '''
-    def __init__(self, args=None, agg_name=None, workspace=None, timeout=None, primary_metric=None, 
-        hp_config_file_name=None, max_workers=1, max_runs=0, xt_config=None, verbose=False, use_azure_storage=False):
+    def __init__(self, args=None, agg_name=None, workspace=None, timeout=None, primary_metric=None, maximize_metric=True,
+        show_single_valued_hps=False, hp_config_file_name=None, max_workers=1, max_runs=0, xt_config=None, verbose=False, use_azure_storage=False):
 
         global plt
         import matplotlib.pyplot as plt
@@ -319,6 +324,7 @@ class SearchHistory():
 
             # set args from XT
             args.primary_metric = primary_metric
+            args.maximize_metric = maximize_metric
             args.hp_def_file = os.path.basename(hp_config_file_name)
             args.max_runs = max_runs
             args.verbose = verbose
@@ -337,6 +343,8 @@ class SearchHistory():
 
         self.ws_name = workspace if workspace else args.workspace
         self.xt_config = xt_config
+        self.hpmax_name = self.args.primary_metric.upper()
+        self.show_single_valued_hps = show_single_valued_hps
 
 
     def init_xtstore(self):
@@ -346,12 +354,11 @@ class SearchHistory():
             self.xtstore = Store(config=self.xt_config)
 
     def load_hp_definitions(self):
-        ''' Get the hyperparameter definitions, downloaded from Azure if necessary. '''
+        ''' Get the hyperparameter definitions from Azure. '''
         hp_config_path = self.DIR_PATH + self.args.hp_def_file
-        if not exists(hp_config_path):
-            self.init_xtstore()
-            job_path = search_helper.get_hp_config_path(self.xtstore, self.ws_name, "job", self.args.job)
-            self.xtstore.download_file_from_job(self.ws_name, self.args.job, job_path, hp_config_path)
+        self.init_xtstore()
+        job_path = search_helper.get_hp_config_path(self.xtstore, self.ws_name, "job", self.args.job)
+        self.xtstore.download_file_from_job(self.ws_name, self.args.job, job_path, hp_config_path)
         self.define_hyperparameters_from_config_yaml(hp_config_path)
 
     def load_runs_from_storage(self):
@@ -394,6 +401,10 @@ class SearchHistory():
 
                 hparam = self.name_hparam_dict[hp_name]
                 
+                # fixup multi-valued HP where we only use a single value
+                if isinstance(hp_value, list) and len(hp_value)==1:
+                    hp_value = hp_value[0]
+
                 if hp_value not in hparam.value_setting_dict:
                     if self.args.verbose:
                         console.print("Skipping {}  (Unexpected hparam value {}:{})".format(run.run_name, hparam.name, hp_value))
@@ -416,13 +427,17 @@ class SearchHistory():
     def load_runs_from_db(self):
         # Get the run summaries.
         self.init_xtstore()
-        filter_dict = {"job_id":self.args.job, "end_id":{"$gt": 0}, 'status':'completed', "metrics.hpmax":{"$exists": True}, 'is_parent':False}
-        fields_dict = {'run_name':1, 'end_id':1, 'hparams':1, 'metrics.hpmax':1}
+        metric_name = "metrics.{}".format(self.args.primary_metric)
+        filter_dict = {"job_id":self.args.job, "end_id":{"$gt": 0}, 'status':'completed', metric_name:{"$exists": True}, 'is_parent':False}
+        fields_dict = {'run_name':1, 'end_id':1, 'hparams':1, metric_name:1}
+        
+        console.print('load_runs_from_db...')
         run_summaries = self.xtstore.get_all_runs("job", self.ws_name, self.args.job, filter_dict, fields_dict, use_cache=False)
+        run_dict = {}
 
         # Create runs from the summaries.
         for run_summary in run_summaries:
-            run = Run(run_summary, self.args.primary_metric, verbose=self.args.verbose)
+            run = Run(run_summary, self.args.primary_metric, self.args.maximize_metric, verbose=self.args.verbose)
             if run.skip:
                 continue
 
@@ -444,6 +459,11 @@ class SearchHistory():
             hp_id__setting_id__list = []
             for hp_name, hp_value in run.hpname_hpvalue_list:
                 hparam = self.name_hparam_dict[hp_name]
+                
+                # fixup multi-valued HP where we only use a single value
+                if isinstance(hp_value, list) and len(hp_value)==1:
+                    hp_value = hp_value[0]
+
                 if hp_value not in hparam.value_setting_dict:
                     if self.args.verbose:
                         console.print("Skipping {}  (Unexpected hparam value {}:{})".format(run.run_name, hparam.name, hp_value))
@@ -454,6 +474,15 @@ class SearchHistory():
             if run.skip:
                 continue
 
+            # Make sure we don't already have this run.
+            if run.run_name in run_dict:
+                # console.print("Ignoring copy of {}".format(run.run_name))
+                # console.print("  current  end_id == {}".format(run.end_id))
+                # console.print("  previous end_id == {}".format(run_dict[run.run_name].end_id))
+                continue
+            else:
+                run_dict[run.run_name] = run
+
             # Add this as a valid run
             run.hp_id__setting_id__list = hp_id__setting_id__list
             run.config_str = str(hp_id__setting_id__list)
@@ -464,8 +493,26 @@ class SearchHistory():
         for i, run in enumerate(self.runs):
             assert isinstance(run.end_id, int)
             if i > 0:
+                if not (run.end_id > self.runs[i-1].end_id):
+                    console.print("Problem found with run.end_id values:")
+                    console.print("  run[{}].end_id == {}   {}   {}".format(i, run.end_id, run.run_name, run.value))
+                    console.print("  run[{}].end_id == {}   {}   {}".format(i-1, self.runs[i-1].end_id, self.runs[i-1].run_name, run.value))
+                    if run.end_id < self.runs[i-1].end_id:
+                        console.print("    The expected order is reversed.")
+                    elif run.end_id == self.runs[i-1].end_id:
+                        console.print("    They are equal.")
+                    else:
+                        console.print("    They cannot be compared.")
                 assert run.end_id > self.runs[i-1].end_id
 
+        console.print("runs returned: {:,}, runs loaded: {:,}, primary_metric: {}, maximize_metric: {}".format( \
+            len(run_summaries), len(self.runs), self.args.primary_metric, self.args.maximize_metric))
+
+        if self.args.maximize_metric:
+            console.print("MAXIMIZING: {}".format(self.args.primary_metric))
+        else:
+            console.print("MINIMIZING: {}".format(self.args.primary_metric))
+
     def populate_runsets(self, global_runset):
         ''' Groups runs into runsets that share the same HP combination. '''
         prior_mean = global_runset.sample_mean
@@ -492,9 +539,9 @@ class SearchHistory():
                 if self.args.verbose:
                     console.print("New trophy goes to runset {}".format(best_runset.id))
                     if best_runset.post_mean is None:
-                        console.print("    HPMAX = None")
+                        console.print("    {} = None".format(self.hpmax_name))
                     else:
-                        console.print("    HPMAX = {:9.3f}".format(best_runset.post_mean))
+                        console.print("    {} = {:9.3f}".format(self.hpmax_name, best_runset.post_mean))
                     if best_runset.dn is not None:
                         if best_runset.dn.post_mean is None:
                             console.print("    prev  = None")
@@ -547,6 +594,16 @@ class SearchHistory():
             self.hparams.append(hp)
             self.name_hparam_dict[hpname] = hp
 
+    def show_hp_in_report(self, hp_name):
+        show = self.show_single_valued_hps
+        if not show:
+            # only show hps with more than 1 value
+            hp = self.name_hparam_dict[hp_name]
+            if len(hp.value_setting_dict) > 1:
+                show = True
+
+        return show
+
     def evaluate(self):
         # Get the hyperparameters and the runs.
         self.load_hp_definitions()
@@ -588,7 +645,7 @@ class SearchHistory():
         for hp in self.hparams:
             hp_names.append(hp.name)
 
-        fixed_names = ['RUNSET', 'SIZE', 'BEST_FOR', 'EST_HPMAX', 'BEST_RUN']
+        fixed_names = ['RUNSET', 'SIZE', 'BEST_FOR', 'EST_{}'.format(self.hpmax_name), 'BEST_RUN']
         avail_cols = hp_names + fixed_names
 
         records = []
@@ -597,9 +654,13 @@ class SearchHistory():
             best = '{}'.format(trophy.runset.runs[0].run_name)  # To show only the best run for each runset.
 
             hp_values = trophy.runset.report_configuration_string().split()
-            hd = {header:utils.make_numeric_if_possible(value) for header, value in zip(hp_names, hp_values)}
+            hd = {header:utils.make_numeric_if_possible(value) for header, value in zip(hp_names, hp_values) if self.show_hp_in_report(header)}
+
+            if self.args.maximize_metric:
+                fixed_values = [trophy.runset.id, len(trophy.runset.runs), trophy.num_runs, trophy.runset.post_mean, best]
+            else:
+                fixed_values = [trophy.runset.id, len(trophy.runset.runs), trophy.num_runs, -trophy.runset.post_mean, best]
 
-            fixed_values = [trophy.runset.id, len(trophy.runset.runs), trophy.num_runs, trophy.runset.post_mean, best]
             fd = {name: value for name, value in zip(fixed_names, fixed_values)}
 
             # merge fd into hd
@@ -608,7 +669,7 @@ class SearchHistory():
 
             # calc data for plot
             y = trophy.runset.post_mean
-            d = math.sqrt(trophy.runset.post_var)
+            d = trophy.runset.post_st_dev
 
             for i in range(trophy.num_runs):
                 xs[x] = x + 1
@@ -620,7 +681,7 @@ class SearchHistory():
         builder = ReportBuilder(self.xt_config, self.xtstore)
 
         # build report (borrow config file settings from run-reports)
-        text, row_count = builder.build_formatted_table(records, avail_cols=avail_cols, col_list=avail_cols, 
+        text, row_count = builder.build_formatted_table(records, avail_cols=avail_cols, col_list=hd.keys(), 
             report_type="run-reports", max_col_width=50)
 
         # print report
@@ -643,8 +704,9 @@ def parse_args(args_list=None):
     parser.add_argument('--no_download', action='store_true', help='To save time by skipping download of runs for a completed, previously viewed job.')
     parser.add_argument('--job_dir', action='store', help='Path to the parent directory of the given job, where files will be stored. Defaults to dilbert/jobs/', default='../jobs')
     parser.add_argument('--max_runs', action='store', help='Terminate the evaluation after this many runs.', type=int, default=0)
-    parser.add_argument('--metric', action='store', help='(For old jobs) Name of the metric maximized by HP tuning. Defaults to hpmax.', default='hpmax')
-    parser.add_argument('--hp_def_file', action='store', help='(For old jobs) Name of the file defining the HPs.', default='uploaded_hp_config.yaml')
+    parser.add_argument('--primary_metric', action='store', help='(For old jobs) Name of the metric maximized by HP tuning. Defaults to hpmax.', default='hpmax')
+    parser.add_argument('--maximize_metric', action='store', help='True if the primary metric should be maximized. Defaults to True.', default=True)
+    parser.add_argument('--hp_config_file_name', action='store', help='(For old jobs) Name of the file defining the HPs.', default='uploaded_hp_config.yaml')
     parser.add_argument('--workspace', action='store', help='name of the workspace for the job', default='')
     parser.add_argument('--verbose', action='store_true', help='Print extra output to the console for debugging.')
     parser.add_argument('--use_azure_storage', action='store_true', help='Pulls run results from Azure Storage instead of SQL DB (the default).')
