@@ -882,6 +882,8 @@ class ImplCompute(ImplBase):
     @flag("distributed", default="$general.distributed", help="when True, the multiple nodes will be put into distributed training mode")
     @hidden("distributed-training", default="$aml-options.distributed-training", help="the name of the backend process to use for distributed training")
     @option("docker", type=str, help="the name of the docker entry to use with the target (from one of the entries in the config file [dockers] section")
+    @hidden("docker-pull-timeout", default="$general.docker-pull-timeout", type=str, help="duration to wait for docker pull cmd (with retries)")
+    @hidden("docker-other-options", default="$general.docker-other-options", type=str, help="extra user options to append to docker run command")
     @flag("dry-run", help="when True, the planned runs are displayed but not submitted")
     @hidden("early-policy", default="$early-stopping.early-policy", help="the name of the early-stopping policy to use (bandit, median, truncation, none)")
     @option("escape", type=int, default=0, help="breaks out of attach or --monitor loop after specified # of seconds")
@@ -893,12 +895,15 @@ class ImplCompute(ImplBase):
     @hidden("fn_generated_config", default="$hyperparameter-search.fn-generated-config", type=str, help="the name for the generated HP config file")
     @hidden("framework", default="$aml-options.framework", help="the name of the framework to be installed for the run (pytorch, tensorflow, chainer)")
     @hidden("fw-version", default="$aml-options.fw-version", help="the framework version number")
+    @option("goal-metric", default="$hyperparameter-search.goal-metric", type=float, help="goal for primary metrics (stops CCD hp search when reached)")
     #@hidden("grok-server", default="$logging.grok-server", help="the ip address of the grok-server to be used for mirroring")
     @flag("hold", help="when True, the Azure Pool (VM's) are held open for debugging)")
     @option("hp-config", default="$hyperparameter-search.hp-config", type=str, help="the path of the hyperparameter config file")
+    @flag("jupyter-monitor", help="when True, a Jupyter notebook is created to monitor the run")
     @hidden("log", default="$logging.log", help="specifes if run-related events should be logged")
     @hidden("log-reports", default="$logging.log-reports", help="specifies if CPU, GPU, and MEMORY reports should be included in setup log")
     @option("low-pri", type=bool, help="when true, use low-priority (preemptable) nodes for this job")
+    @option("max-passes", default="$hyperparameter-search.max-passes", type=int, help="used to limit number of passes over hyperparameters in hp search")
     @option("max-minutes", default="$hyperparameter-search.max-minutes", type=int, help="the maximum number of minutes the run can execute before being terminated")
     @hidden("max-seconds", type=int, default="$aml-options.max-seconds", help="the maximum number of seconds this run will execute before being terminated")
     @option("max-run-delay", default="$database.max-run-delay", type=float, help="the maximum random delay applied to each run in the job")
@@ -906,17 +911,20 @@ class ImplCompute(ImplBase):
     @option("max-workers", type=int, default="$general.max-run-workers", help="the max number of background workers to use during run command")
     @hidden("maximize-metric", default="$general.maximize-metric", help="whether to minimize or maximize value of primary metric")
     @hidden("merge-batch-logs", type=int, default="$logging.merge-batch-logs", help="replaces STDOUT.txt and STDERR.txt with STDBOTH.txt")
-    @hidden("mirror-dest", default="$logging.mirror-dest", help="the location where mirrored information is store (none, storage, grok)")
+    @hidden("mirror-dest", default="$logging.mirror-dest", help="the location where mirrored information is stored (none, storage, grok)")
     @hidden("mirror-files", default="$logging.mirror-files", help="the wildcard path that specifies files to be mirrored")
     @option("model-action", default="$model.model-action", help="the model action to take on the target, before run is started")
     @hidden("model-local", default="$model.model-local", help="the path on the local machine specifying where the model for this job resides")
     @hidden("model-share-path", default="$model.model-share-path", help="the model share name for the model")
     @flag("model-writable", default="$model.model-writable", help="when true, a mounted model path can be written to")
-    @flag("jupyter-monitor", help="when True, a Jupyter notebook is created to monitor the run")
     @option("monitor", default="$general.monitor", values=["new", "bg", "same", "none"], help="how to monitor primary run of the new job")
+    @hidden("mount-retry_count", type=int, default="$general.mount-retry-count", help="the number of times to retry each blobfuse mount command")
+    @hidden("mount-retry_interval", type=str, default="$general.mount-retry-interval", help="the time to sleep between retries of blobfuse mount command")
     @flag("multi-commands"   , help="the script file contains multiple run commands (one per line)")
+    @option("node-delay", type=str, default="$general.node-delay", help="maximum time to randomly delay start of node execution")
     @option("node-repeat", type=int, help="the number of times to repeat each hyperparameter set on each node")
     @option("nodes", type=int, help="the number of normal (non-preemptable) nodes to allocte for this run")
+    @option("nowrap", type=bool, help="when true, don't generate a wrapper script for XT setup; run user script directly")
     @hidden("option-prefix", default="$hyperparameter-search.option-prefix", help="the prefix to be used for specifying hyperparameter options to the script")
     @option("parent-script", type=str, help="path of script used to initialize the target for repeated runs of primary script")
     @hidden("pip-freeze", default="$logging.pip-freeze", help="when true, installed pip packges are included in the setup log")
@@ -926,13 +934,15 @@ class ImplCompute(ImplBase):
     @hidden("report-rollup", default="$run-reports.report-rollup", help="whether to rollup metrics by primary metric or just use last reported metric set")
     @option("resume-name", help="when resuming a run, this names the previous run")
     @option("runs", default=None, type=int, help="the total number of runs across all nodes (for hyperparameter searches)")
+    @option("runs-per-set", default="$hyperparameter-search.runs-per-set", type=int, help="how many runs to do for each CCD hp set explored")
     @option("schedule", default="static", values=["static", "dynamic"], help="specifies if runs are pre-assigned to each node or allocate on demand")
-    @option("search-type", values=["random", "grid", "bayesian", "dgd"], default="$hyperparameter-search.search-type", help="the type of hyperparameter search to perform")
+    @option("search-type", values=["random", "grid", "bayesian", "dgd", "ccd"], default="$hyperparameter-search.search-type", help="the type of hyperparameter search to perform")
     @option("seed", default=None, help="the random number seed that can be used for reproducible HP searches")
     @option("setup", type=str, help="the name of the setup entry to use with the target (from one of the entries in the config file [setups] section")
     @option("sku", help="the name of the Philly SKU to be used (e.g, 'G1')")
     @hidden("slack-factor", default="$early-stopping.slack-factor", type=float, help="(bandit only) specified as a ratio, the delta between this eval and the best performing eval")
     @hidden("slack-amount", default="$early-stopping.slack-amount", type=float, help="(bandit only) specified as an amount, the delta between this eval and the best performing eval")
+    @option("sleep-on-exit", type=str, default="0", help="the amount of time to sleep (e.g., '45m'), before controller exits it's process")
     @flag("static-search",  default="$hyperparameter-search.static-search", help="if true, hyperparameter searches are performed at job submit time, when possible")
     @hidden("storage", default=None, type=str, help="name of storage service to be used for this run")
     @option("submit-logs", default=None, help="specifies a directory to which log files for the submit are saved")
@@ -966,6 +976,11 @@ class ImplCompute(ImplBase):
 
         target = args["target"]
         storage = args["storage"]
+        nowrap = args["nowrap"]
+
+        if nowrap:
+            # this debug option doesn't use merged logs
+            args["merge_batch_logs"] = False
 
         if not target:
             ss_info = self.config.get_store_info()
