@@ -206,7 +206,7 @@ class ImplHelp(ImplBase):
         self.help_topics(topic, browse, prefix="internals", title="internal help topics")
 
     def help_version(self):
-        console.print(constants.BUILD)
+        console.print("XT {}".format(constants.BUILD))
 
     def command_summary(self):
 
