@@ -668,7 +668,7 @@ class ImplUtilities(ImplBase):
     def docker_login(self, target, docker):
 
         if not target:
-            ss_info = self.get_store_info()
+            ss_info = self.config.get_store_info()
             target = utils.safe_value(ss_info, "target")
 
         reg_creds = self.get_registry_creds(target, docker)
@@ -693,7 +693,7 @@ class ImplUtilities(ImplBase):
     def docker_logout(self, target, docker):
 
         if not target:
-            ss_info = self.get_store_info()
+            ss_info = self.config.get_store_info()
             target = utils.safe_value(ss_info, "target")
 
         reg_creds = self.get_registry_creds(target, docker)
