@@ -18,6 +18,7 @@ from xtlib import run_helper
 from xtlib import job_helper
 from xtlib import store_utils
 from xtlib.hp_set import HpSetFormatter
+from xtlib.report_builder import ReportBuilder   
 
 PRESMOOTH = "_PRE-SMOOTH_"
 ERR = "_ERR_"
@@ -26,7 +27,7 @@ MIN = "_MIN_"
 MAX = "_MAX_"
 
 class PlotBuilder():
-    def __init__(self, store, run_names, col_names, x_col, layout, break_on, title, show_legend, plot_titles,
+    def __init__(self, config, store, run_names, col_names, x_col, layout, break_on, title, show_legend, plot_titles,
             legend_titles, smoothing_factor, plot_type, timeout,
             aggregate, shadow_type, shadow_alpha, run_log_records, style, show_toolbar, max_traces,
             group_by, error_bars, show_plot, save_to, x_label, x_labels_col,
@@ -34,8 +35,9 @@ class PlotBuilder():
             x_min, x_max, y_min, y_max, alpha, color_indexes, line_styles, line_sizes, timebase, x_format, y_format, 
             x_share, y_share, background_color, grid_color, clean, width, height, highlight, color_highlight,
             legend_suffix, col_source, x_int, y_int, bins, legend_vars, margins, metric_aliases, y_ticks,
-            first, last, skip, plot_args):
+            first, last, skip, named_columns, plot_args):
         
+        self.config = config
         self.store = store
         self.group_names = None
         self.run_names = run_names
@@ -108,6 +110,9 @@ class PlotBuilder():
         self.last = last
         self.skip = skip
         self.hp_set_formatter = HpSetFormatter()
+        self.hp_sets_by_name = {}
+        self.hp_sets_names_plotted = {}
+        self.named_columns = named_columns
 
         if colors:
             self.colors = colors
@@ -171,7 +176,9 @@ class PlotBuilder():
         elif group_by in record:
             value = record[group_by]
             if group_by == "hp_set":
-                value = self.hp_set_formatter.format_hpset_simple(value)
+                new_value = self.hp_set_formatter.format_hpset_simple(value)
+                self.hp_sets_by_name[new_value] = value
+                value = new_value
 
         else:
             raise Exception("unrecognized group-by name: " + str(group_by))
@@ -837,6 +844,11 @@ class PlotBuilder():
         return series, plot_count
 
     def plot_data(self, data_frames_by_cols):
+        if self.hp_sets_by_name:
+            # print a console report of the hp_set names used in the plot
+            records = [{"hp_set": self.hp_sets_by_name[hp_set_name]} for hp_set_name in self.hp_sets_by_name]
+            self.hp_set_report(records)
+
         console.diag("starting to plot data")
         self.data_frames_by_cols = data_frames_by_cols
 
@@ -935,6 +947,11 @@ class PlotBuilder():
             self.plot_middle(data_frames_by_cols, ax, group_name, col, \
                 self.x_col, x_label, line_index, plot_index)
 
+        # if self.hp_sets_names_plotted:
+        #     # print a console report of the hp_set names used in the plot
+        #     records = [{"hp_set": self.hp_sets_by_name[hp_set_name]} for hp_set_name in self.hp_sets_names_plotted]
+        #     self.hp_set_report(records)
+
         self.finish_plot(plt, fig, plots, pylab)
 
     def finish_plot(self, plt, fig, plots, pylab):
@@ -1187,7 +1204,16 @@ class PlotBuilder():
         return cmap
 
     def plot_middle(self, data_frames_by_cols, ax, group_name, col, x_col, x_label, line_index, plot_index):
-        
+
+        # should this series be hidden?        
+        line_title = self.legend_titles[line_index % len(self.legend_titles)]
+        if line_title == "-":
+            # hide series with user-specified blank titles
+            return
+
+        if self.group_by == "hp_set":
+            self.hp_sets_names_plotted[group_name] = 1
+
         if self.background_color:
             ax.set_facecolor((self.background_color))            
 
@@ -1268,10 +1294,6 @@ class PlotBuilder():
                 line_title += self.legend_suffix
 
             line_title = self.fixup_text(line_title, group_name, col)
-            if line_title == "-":
-                # hide series with user-specified blank titles
-                return
-
         else:
             line_title = None
             
@@ -1370,6 +1392,39 @@ class PlotBuilder():
             ax.set_xticks(x_values)
             ax.set_xticklabels(x_labels)
 
+    def hp_set_report(self, records):
+        builder = ReportBuilder(self.config, self.store)
+        common = True
+        args = {"hp_set": "simple_plus_columns"}
+
+        if self.named_columns:
+            user_columns = self.config.get("named-columns", self.named_columns)
+        else:
+            user_columns = self.config.get("run-reports", "columns")
+
+        if not "hp_set" in user_columns:
+            user_columns.insert(0, "hp_set")
+
+        # print common hyperparameters on top of report
+        if common and self.hp_set_formatter.hp_common_set:
+            console.print("\nCommon hyperparameters:")
+            for hp,value in self.hp_set_formatter.hp_common_set.items():
+                console.print("  {}: {}".format(hp, value))
+            console.print("")
+
+        # print report of hp_set names and their param/values
+        lines, row_count, was_exported = builder.build_report(records, user_columns=user_columns, report_type="run-reports", args=args)
+
+        # store_name = self.config.get("store")
+        # workspace = self.workspace
+        # console.print("runs on {}/{}:".format(store_name, workspace))
+
+        if row_count > 0:
+            console.print("")
+
+            for line in lines:
+                console.print(line)
+
     def fixup_text(self, text, group_name, col):
         if text:
             group_info = self.group_info[group_name] if group_name else None
