@@ -371,7 +371,7 @@ class RemotePsmClient():
 
         return cancelled, status
 
-    def read_log_file(self, fn_entry, start_offset, end_offset):
+    def read_log_file(self, fn_entry, start_offset, end_offset, log_source=None):
         '''
         Description:
             Each SSH call to read a file takes about 1.5 secs (too long), so
