@@ -503,24 +503,28 @@ class ReportBuilder():
 
         # from the current set of records, calculate the set of hyperparameters that change between runs
         self.hp_set_formatter.build_hp_set_names(records)
+        hp_set_index = user_columns.index("hp_set") if "hp_set" in user_columns else -1
 
-        if True:       # hp_set_display == "hidden":
-            # remove all hp_set column/format info
-            cols = list(user_columns)
-            for col in cols:
-                if col == "hp_set" or col.startswith("hp_set=") or col.startswith("hp_set:"):
-                    user_columns.remove(col)
+        # if hp_set_display != "simple_plus_columns":
+        #     # remove all hp_set column/format info
+        #     cols = list(user_columns)
+        #     for col in cols:
+        #         if col == "hp_set" or col.startswith("hp_set=") or col.startswith("hp_set:"):
+        #             user_columns.remove(col)
+
+        def _set_or_append(values, value, index): 
+            values[index] = value if index > -1 else values.append(value)
 
         if hp_set_display == "changed":
-            user_columns.append("hp_set:$hpset_changed")
+            _set_or_append(user_columns, "hp_set:$hpset_changed", hp_set_index)
 
-        if hp_set_display == "simple":
-            user_columns.append("hp_set:$hpset_simple")
+        if hp_set_display == "simple" or hp_set_display == "simple_plus_columns":
+            _set_or_append(user_columns, "hp_set:$hpset_simple", hp_set_index)
 
-        elif hp_set_display == "full":
-            user_columns.append("hp_set")
+        if hp_set_display == "full":
+            _set_or_append(user_columns, "hp_set", hp_set_index)
 
-        elif hp_set_display == "columns":
+        if hp_set_display == "columns" or hp_set_display == "simple_plus_columns":
             if self.hp_set_formatter.hp_common_set:
                 # for each run record, convert hp_set column into new columns in the record 
                 for record in records:
@@ -531,7 +535,8 @@ class ReportBuilder():
                         full_hp_name = "hparams." + hp
                         record[full_hp_name] = value
 
-                    del record["hp_set"]
+                    if hp_set_display == "columns":
+                        del record["hp_set"]
 
                 # add "hparams.*" to ensure we display all of the hyperparameters
                 #user_columns.append("hparams.*")
@@ -541,7 +546,7 @@ class ReportBuilder():
         # store for later use
         self.user_col_args = user_col_args
 
-        fn_export = args["export"]
+        fn_export = utils.safe_value(args, "export")
         if fn_export:
             fn_ext = os.path.splitext(fn_export)[1]
             if not fn_ext:
@@ -557,7 +562,7 @@ class ReportBuilder():
             lines += [line]
             was_exported = True
         else:
-            number_groups = args["number_groups"] if "number_groups" in args else False
+            number_groups =  utils.safe_value(args, "number_groups")
             actual_cols = list(user_col_args.keys())
 
             text, row_count = self.build_formatted_table(records, avail_cols=avail_list, col_list=actual_cols, 
@@ -739,7 +744,7 @@ class ReportBuilder():
 
         if self.config:
             if not max_col_width:
-                max_col_width = int(self.config.get(report_type, "max-width"))    
+                max_col_width = utils.to_int_or_none(self.config.get(report_type, "max-width"))    
                 
             precision = self.config.get(report_type, "precision")
             significance = self.config.get(report_type, "significance")
