@@ -8,6 +8,7 @@ import sys
 import json
 import atexit
 import random
+import numpy as np
 from collections import OrderedDict
 
 # xtlib
@@ -263,15 +264,34 @@ class Run():
             return
 
         print("run.close() starting...")
-        
+
         # careful not to trigger store method if not needed so that local script runs
         # don't trigger need for authentication unnecessarily 
         has_store = False
         if self.store and self.store.actual_store is not None:
             has_store = True
 
+        if self.context:
+            context = self.context
+            if context.hp_config and context.search_style == "dynamic":
+                # this run is part of a dynamic HP search: ensure primary_metrics is in logged metrics
+                primary_metric = context.primary_metric
+                
+                filter_dict = {"run_name": self.run_name}
+                fields_dict = {"metrics": 1}
+                records = self.store.database.get_info_for_runs(self.ws_name, filter_dict, fields_dict)
+
+                logged_metrics = utils.safe_cursor_value(records, "metrics")
+                if not logged_metrics or not primary_metric in logged_metrics:
+                    print("raising error...")
+                    errors.user_error("primary_metric '{}' not logged by this run (dynamic hyperparameter search runs must log their primary metric at least once)".format(primary_metric))
+  
         if self.xt_logging and self.direct_run and has_store and self.context:
             context = self.context
+            print(" context.hp_config=",  context.hp_config)
+            print(" context.search_style=",  context.search_style)
+            print(" context.primary_metric=",  context.primary_metric)
+
             status = "completed"
             exit_code = 0
             rundir = "."
@@ -345,6 +365,12 @@ class Run():
         #console.print("log_metrics: self.store=", self.store, ", xt_logging=", self.xt_logging)
 
         dd = dict(data_dict)
+
+        # # fix up metric values (numpy floats)
+        # for key, value in dd.items():
+        #     if isinstance(value, (np.float32, np.float64)):
+        #         dd[key] = value.item()
+
         if step_name and step_name in dd:
            step_num = dd[step_name]
         else:
@@ -374,6 +400,7 @@ class Run():
         # each metric set may have a unique step name so log it each time with metrics
         dd[constants.STEP_NAME] = step_name
 
+        # log to XT
         if self.store and self.xt_logging:
             #console.print("logging run_event for metrics...")
             self.store.log_run_event(self.ws_name, self.run_name, "metrics", dd, job_id=self.job_id)
@@ -386,22 +413,24 @@ class Run():
                 if self.store.database:
                     self.store.database.update_run_info(self.ws_name, self.run_name, ddx)
 
+        # log to AML
         if self.is_aml and self.aml_logging:
             for name, value in dd.items():
                 self.aml_run.log(name, value)
 
+        # log to TENSORBOARD
         if stage is None or stage == "train":
 
             # log TRAIN metrics
             if self.train_writer:
                 for name, value in data_dict.items():
-                    if name != step_name:
+                    if name != step_name and not isinstance(value, str):
                         self.train_writer.add_scalar(name, value, global_step=step_num)
                 self.train_writer.flush()
 
             if self.train_writer2:
                 for name, value in data_dict.items():
-                    if name != step_name:
+                    if name != step_name and not isinstance(value, str):
                         self.train_writer2.add_scalar(name, value, global_step=step_num)
                 self.train_writer2.flush()
 
