@@ -447,11 +447,6 @@ def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None,
 
     builder = ReportBuilder(config, store)
 
-    # get list of specified runs
-    # pure_run_list, actual_ws = expand_run_list(store, db, workspace, run_list)
-    # if run_list and not pure_run_list:
-    #     errors.general_error("no matching runs found")
-
     # build a filter dict for all specified filters
     filter_dict = build_run_filter_dict(store, workspace, run_list, user_to_actual=user_to_actual, 
         builder=builder, args=args)
@@ -475,11 +470,16 @@ def get_filtered_sorted_limit_runs(store, config, show_gathering, col_dict=None,
     # remove key info from _id in records
     store_utils.simplify_records_id(records)
 
-    # # remove key from pure_run_list
-    # pure_run_list = [pr.split("/")[-1] for pr in pure_run_list]
+    sort = utils.safe_value(args, "sort")
+    if preserve_order and not sort:
+        # get list of specified runs
+        pure_run_list, actual_ws = expand_run_list(store, db, workspace, run_list)
+        if run_list and not pure_run_list:
+            errors.general_error("no matching runs found")
 
-    # if preserve_order:
-    #     records = order_runs_by_user_list(records, pure_run_list)
+        # remove key from pure_run_list
+        pure_run_list = [pr.split("/")[-1] for pr in pure_run_list]
+        records = order_runs_by_user_list(records, pure_run_list)
 
     console.diag("end of: get_filtered_sorted_limit_runs")
 
@@ -535,9 +535,9 @@ def list_runs(store, config, args, compare=False):
         console.print("runs on {}/{}:".format(store_name, workspace))
 
         # print common hyperparameters on top of report
-        if utils.safe_value(args, "common") and builder.hp_common_set:
+        if utils.safe_value(args, "common") and builder.hp_set_formatter.hp_common_set:
             console.print("\nCommon hyperparameters:")
-            for hp,value in builder.hp_common_set.items():
+            for hp,value in builder.hp_set_formatter.hp_common_set.items():
                 console.print("  {}: {}".format(hp, value))
             console.print("")
 
