@@ -497,7 +497,7 @@ class Runner():
                 if " " in timeout:
                     raise Exception("illegal duration specified for general.docker-pull-timeout (try: 30m)")
 
-        docker_image, login_server, docker_registry = self.config.get_docker_info(target, docker_name, required=False)
+        docker_image, login_server, docker_registry, _ = self.config.get_docker_info(target, docker_name, required=False)
         creds_required = utils.make_numeric_if_possible( utils.safe_value(docker_registry, "login") )
 
         setup_def = self.config.get("setups", setup_name, suppress_warning=True)
@@ -844,7 +844,7 @@ class Runner():
 
         # ADJUST CMDS: this allows backend to write scripts to snapshot dir, if needed, as a way of adjusting/wrapping run commands
         args["job_id"] = job_id
-        self.backend.adjust_run_commands(job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, args=args)
+        self.backend.adjust_run_commands(job_id, job_runs, using_hp, experiment, service_type, snapshot_dir, env_vars, args=args)
 
         # upload CODE from snapshot_dir
         code_upload = args["code_upload"]
