@@ -190,8 +190,8 @@ class StoreBlobObjs():
         new_path = "/".join(path.split("/")[1:])
         return new_path
 
-    def _create_blob(self, ws_name, blob_path, text, fail_if_exists=False):
-        self.provider.create_blob(ws_name, blob_path, text, fail_if_exists=fail_if_exists)
+    def _create_blob(self, ws_name, blob_path, text, fail_if_exists=False, etag=None):
+        self.provider.create_blob(ws_name, blob_path, text, fail_if_exists=fail_if_exists, etag=etag)
 
     def _append_blob(self, ws_name, blob_path, text, append_with_rewrite=False):
         #console.print("append: ws_name=", ws_name, ", blob_path=", blob_path, ", text=", text)
@@ -962,9 +962,9 @@ class BlobsObject():
                 path = base_path
         return path
 
-    def create_file(self, path, text, block_size=None):
+    def create_file(self, path, text, block_size=None, fail_if_exists=False, etag=None):
         path = self._expand_path(path)
-        return self.store._create_blob(self.container, path, text)
+        return self.store._create_blob(self.container, path, text, fail_if_exists=fail_if_exists, etag=etag)
 
     def append_file(self, fn, text):
         path = self._expand_path(fn)
