@@ -652,6 +652,10 @@ class StoreV1():
         items = [item["_id"] for item in items]
         return items
 
+    def get_node_id_of_run(self, ws_name, run_name):
+        # for now, fail soft (node_id's are not supported on mongo v1)
+        return 0
+
     def end_run(self, ws_name, run_name, status, exit_code, hparams_dict, metrics_rollup_dict, end_time=None, 
         aggregate_dest=None, dest_name=None):
 
@@ -972,13 +976,13 @@ class StoreV1():
         rf = self.run_files(ws_name, run_name, use_blobs=True)
         return rf.delete_file(filename)
 
-    def delete_run_subfolder_and_files(self, ws_name, run_name, subfolder_name):
+    def delete_run_subfolder_and_files(self, ws_name, run_name, subfolder_name, job_id=None):
         '''delete all files under the specified folder_name.
         '''
         rf = self.run_files(ws_name, run_name, use_blobs=True)
         return rf.delete_files(subfolder_name + "/**")
 
-    def does_run_file_exist(self, ws_name, run_name, run_fn):
+    def does_run_file_exist(self, ws_name, run_name, run_fn, job_id=None):
         '''return True if the specified run file 'run_fn' exists.
         '''
         #return self.helper.does_run_file_exist(ws_name, run_name, run_fn)
@@ -1040,12 +1044,12 @@ class StoreV1():
 
     #---- JOB FILES ----
 
-    def create_job_file(self, ws_name, job_name, job_path, text):
+    def create_job_file(self, ws_name, job_name, job_path, text, fail_if_exists=False, etag=None):
         '''create a job file specified by 'job_path' from the text 'text'.
         '''
         #self.helper.create_job_file(job_name, job_path, text)
         jf = self.job_files(ws_name, job_name, use_blobs=True)
-        return jf.create_file(job_path, text)
+        return jf.create_file(job_path, text, fail_if_exists=fail_if_exists, etag=etag)
 
     def append_job_file(self, ws_name, job_name, job_path, text):
         '''append text 'text' to the job file 'job_path'.
@@ -1161,6 +1165,9 @@ class StoreV1():
     def job_files(self, ws_name, job_name, use_blobs=False):
         return self.helper.job_files(job_name, use_blobs)
 
+    def get_current_blob_etag(self):
+        return self.helper.provider.current_blob_etag
+
 # sample code for path objects
 #   wp = store.WorkspaceFiles(ws_name="ws1")  
 #   wp.create_file("test.txt", "this is test.txt contents")
