@@ -73,6 +73,9 @@ def is_philly_box(box_name):
 def is_itp_box(box_name):
     return (box_name and "-itp-" in box_name)
 
+def is_singularity_box(box_name):
+    return (box_name and "-singularity-" in box_name)
+
 def is_service_box(box_name):
     return box_name and job_helper.is_job_id(box_name) and "-" in box_name
 
@@ -791,4 +794,10 @@ def get_user_columns(columns_arg, report_name, config):
     else:
         columns = config.get(report_name, "columns")
 
-    return columns
\ No newline at end of file
+    return columns
+
+def to_int_or_none(value):
+    if value is not None:
+        value = int(value)
+
+    return value
\ No newline at end of file
